********************
Contributing to Nept
********************

Thanks for your interest in contributing to nept!
Issues and pull requests are always welcome.

Reporting issues
----------------

When reporting issues please provide as much detail as possible.

Contributing code
-----------------

If you want to fix a bug or add a feature to nept, we welcome 
pull requests. Please fill out all relevant sections in the pull request
template and adhere to our `style guide <style_guide.rst>`_.